==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ListPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelContentRefreshedEventArgsDescription } from "./ListPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
var ListPanelContentRefreshedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ListPanelContentRefreshedEventArgsDescriptionMetadata, _super);
    function ListPanelContentRefreshedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelContentRefreshedEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
            ListPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelContentRefreshedEventArgsDescriptionMetadata.c(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        if (a.k(ListPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.c = function (a) {
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.d = function (a) {
        ListPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
        a.ad("ListPanelContentRefreshedEventArgs", function () { return new ListPanelContentRefreshedEventArgsDescription(); });
        a.ac("ListPanelContentRefreshedEventArgs", ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.$t = markType(ListPanelContentRefreshedEventArgsDescriptionMetadata, 'ListPanelContentRefreshedEventArgsDescriptionMetadata');
    ListPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ListPanelContentRefreshedEventArgsDescriptionMetadata;
}(Base));
export { ListPanelContentRefreshedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/ListPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelContentRefreshedEventArgsDescription } from "./ListPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
var ListPanelContentRefreshedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ListPanelContentRefreshedEventArgsDescriptionMetadata, _super);
    function ListPanelContentRefreshedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelContentRefreshedEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
            ListPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelContentRefreshedEventArgsDescriptionMetadata.c(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        if (a.k(ListPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.c = function (a) {
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.d = function (a) {
        ListPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
        a.ae("ListPanelContentRefreshedEventArgs", function () { return new ListPanelContentRefreshedEventArgsDescription(); });
        a.ad("ListPanelContentRefreshedEventArgs", ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.$t = markType(ListPanelContentRefreshedEventArgsDescriptionMetadata, 'ListPanelContentRefreshedEventArgsDescriptionMetadata');
    ListPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ListPanelContentRefreshedEventArgsDescriptionMetadata;
}(Base));
export { ListPanelContentRefreshedEventArgsDescriptionMetadata };
